@@ -11,21 +11,29 @@ import platform
 
 class Area_plot: 
   # read data
-  def __init__(self, file):
-
-      self.path = self.get_cwd()
-      self.data = self.read_file(file, self.path)
-      self.path_img = self.get_cwd()
-
-
-  def get_cwd(self):
-      # get the current path of file .
+  def __init__(self, path=os.getcwd(),file='museum_visitors_line.csv'):
       if platform.system().lower() == 'windows':
-          path = os.getcwd() + '/'
-
+          path = path + '/'
+          self.path_img = os.getcwd() + '/'
       elif platform.system().lower() == 'linux':
-          path = os.getcwd().replace('/', '\\') + '/'
-      return path
+          path = path.replace('/', '\\') + '/'
+          self.path_img = os.getcwd().replace('/', '\\') + '/'
+      # self.data = self.read_file(file, path)
+
+      # self.path = self.get_cwd()
+      # self.data = self.read_file("numseunm_visitors.csv", path)
+      # self.path=path
+      # self.path_img = self.get_cwd()
+
+
+  # def get_cwd(self):
+  #     # get the current path of file .
+  #     if platform.system().lower() == 'windows':
+  #         path = os.getcwd() + '/'
+  #
+  #     elif platform.system().lower() == 'linux':
+  #         path = os.getcwd().replace('/', '\\') + '/'
+  #     return path
 
   def read_file(self, file, path):
       """Read different types of files and return pandas dataframe.
@@ -117,7 +125,8 @@ class Area_plot:
   # y_col_name: ['y_column_name_a','y_column_name_b'...]
   # plot_type: type of plot: stack ,percentage or simple
   # paper_type : 'single' or 'double'
-  def area(self, file,  x_col_name=None, y_col_name=None, plot_type=None,paper_type=None,**kwargs):
+  def area(self,  x_col_name=None, y_col_name=None, plot_type=None,paper_type=None,**kwargs):
+
     
     # Configuration of the line chart
     # plotwidth: width of the plot
@@ -152,6 +161,9 @@ class Area_plot:
     # save_image: True or False as options. If it is True, save chart
     # savefig_bbox_inches: Bounding box in inches
     # file_name: the file name in saving image
+
+    self.data = self.read(file, self.path)
+
     header_list = self.data.columns.values.tolist()
 
     if x_col_name is None:
